searchNodes=[{"doc":"Orchestrator of a back-pressured backfill strategy for Ecto repos. Starts a producer process and dynamically start consumers, the amount of consumers is determined by the availability of resources on your infrastructure, such as available database connections or I/O usage. Define a module to execute the backfill, which must use EctoBackfiller and implement its callbacks. Lets imagine a silly example to illustrate the use of the library. Suppose you have a User schema described as: defmodule MyApp.Users.User do use Ecto.Schema schema do field :email_verified_at , :naive_datetime end end And later on, your business requirements takes you to add email_verified field as a boolean on the schema representing if the user has verified the email. Then you write up the migration and have to update the new column all existing users before execution of the migration. To do so, you can write a module using EctoBackfiller as: defmodule MyApp.Backfills.UserEmailVerifiedBackfill do use EctoBackfiller , repo : MyApp.Repo alias MyApp.Users alias MyApp.Users.User @impl true def query , do : Ecto.Queryable . to_query ( User ) @impl true def step , do : 5 @impl true def handle_batch ( users ) do Enum . each ( users , fn user -&gt; if is_nil ( user . email_verified_at ) do { :ok , user } = Users . update ( user , %{ email_verified : false } ) else { :ok , user } = Users . update ( user , %{ email_verified : true } ) end end ) end end Please mind that the handle_batch/1 callback MUST not modify the results of the query, as it will be used to determine the offset for the next batch of data to be fetched. You also need to guarantee the ordering of the data fetched, since the backfill is based on offsets, if the data is not ordered, you may end up with duplicated or missing data. Now you are ready to start executing it and to do so you must start the Supervisor, which will be named as the backfill module's name, or in other words, it is a unique proccess per backfill module. Inside the application IEx session: alias MyApp.Backfills.UserEmailVerifiedBackfill UserEmailVerifiedBackfill . start_link ( ) :ok UserEmailVerifiedBackfill . add_consumer ( ) :ok UserEmailVerifiedBackfill . start ( ) :ok You may add or more consumers on the fly, based on how the application performs based on the step used and the number of consumers subscribed.","ref":"EctoBackfiller.html","title":"EctoBackfiller","type":"behaviour"},{"doc":"Handles the backfill logic given a list of data","ref":"EctoBackfiller.html#c:handle_batch/1","title":"EctoBackfiller.handle_batch/1","type":"callback"},{"doc":"Queryable used on Repo.all/2 to fetch chunks of data","ref":"EctoBackfiller.html#c:query/0","title":"EctoBackfiller.query/0","type":"callback"},{"doc":"Amount of data fetched per step","ref":"EctoBackfiller.html#c:step/0","title":"EctoBackfiller.step/0","type":"callback"},{"doc":"","ref":"EctoBackfiller.Consumer.html","title":"EctoBackfiller.Consumer","type":"module"},{"doc":"","ref":"EctoBackfiller.Consumer.html#start_link/1","title":"EctoBackfiller.Consumer.start_link/1","type":"function"},{"doc":"","ref":"EctoBackfiller.DynamicSupervisor.html","title":"EctoBackfiller.DynamicSupervisor","type":"module"},{"doc":"Returns a specification to start this module under a supervisor. See Supervisor .","ref":"EctoBackfiller.DynamicSupervisor.html#child_spec/1","title":"EctoBackfiller.DynamicSupervisor.child_spec/1","type":"function"},{"doc":"","ref":"EctoBackfiller.DynamicSupervisor.html#start_consumer/2","title":"EctoBackfiller.DynamicSupervisor.start_consumer/2","type":"function"},{"doc":"","ref":"EctoBackfiller.DynamicSupervisor.html#start_link/1","title":"EctoBackfiller.DynamicSupervisor.start_link/1","type":"function"},{"doc":"","ref":"EctoBackfiller.DynamicSupervisor.html#start_producer/2","title":"EctoBackfiller.DynamicSupervisor.start_producer/2","type":"function"},{"doc":"","ref":"EctoBackfiller.Producer.html","title":"EctoBackfiller.Producer","type":"module"},{"doc":"","ref":"EctoBackfiller.Producer.html#add_consumer/3","title":"EctoBackfiller.Producer.add_consumer/3","type":"function"},{"doc":"","ref":"EctoBackfiller.Producer.html#cancel_subscription/2","title":"EctoBackfiller.Producer.cancel_subscription/2","type":"function"},{"doc":"","ref":"EctoBackfiller.Producer.html#get_consumers/1","title":"EctoBackfiller.Producer.get_consumers/1","type":"function"},{"doc":"","ref":"EctoBackfiller.Producer.html#put_subscription/3","title":"EctoBackfiller.Producer.put_subscription/3","type":"function"},{"doc":"","ref":"EctoBackfiller.Producer.html#running?/1","title":"EctoBackfiller.Producer.running?/1","type":"function"},{"doc":"","ref":"EctoBackfiller.Producer.html#start_link/1","title":"EctoBackfiller.Producer.start_link/1","type":"function"},{"doc":"A back-pressured backfill executor for Ecto repositories.","ref":"readme.html","title":"EctoBackfiller","type":"extras"},{"doc":"def deps do [ { :ecto_backfiller , &quot;~&gt; 0.3.1&quot; } ] end","ref":"readme.html#installation","title":"EctoBackfiller - Installation","type":"extras"},{"doc":"Documentation on how to use the library and important warnings can be found at hexdocs . An example application is also available on the repository to help you visualize the usage of this library.","ref":"readme.html#documentation","title":"EctoBackfiller - Documentation","type":"extras"},{"doc":"Contributions are welcome! Feel free to open issues or pull requests :)","ref":"readme.html#contributing","title":"EctoBackfiller - Contributing","type":"extras"},{"doc":"EctoBackfiller is licensed under Apache License 2.0. Check LICENSE file for more details.","ref":"readme.html#license","title":"EctoBackfiller - License","type":"extras"}]